/*
 * main.c - SHA-2 DLL for mIRC
 * Copyright (c) 2011, D.C. van Moolenbroek, XISE <dc@xise.nl>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#define WIN32_LEAN_AND_MEAN
#include <windows.h>

#include "sha2.h"
#include "hash.h"

typedef int __export __stdcall mircproc(HWND mWnd, HWND aWnd, TCHAR *data,
 TCHAR *parms, BOOL show, BOOL nopause);

typedef struct {
  DWORD mVersion;
  HWND mHwnd;
  BOOL mKeep;
  BOOL mUnicode;
} LOADINFO;

void __export __stdcall LoadDll(LOADINFO *li)
{
#ifdef UNICODE
  li->mUnicode = TRUE;
#endif
}

hash_func sha224_func = {
  (hash_init)   sha224_init,
  (hash_update) sha224_update,
  (hash_final)  sha224_final,
};

mircproc sha224
{
  unsigned char digest[SHA224_DIGEST_SIZE];
  sha224_ctx ctx;

  return hash(data, &sha224_func, digest, sizeof(digest), &ctx, mWnd);
}

hash_func sha256_func = {
  (hash_init)   sha256_init,
  (hash_update) sha256_update,
  (hash_final)  sha256_final,
};

mircproc sha256
{
  unsigned char digest[SHA256_DIGEST_SIZE];
  sha256_ctx ctx;

  return hash(data, &sha256_func, digest, sizeof(digest), &ctx, mWnd);
}

hash_func sha384_func = {
  (hash_init)   sha384_init,
  (hash_update) sha384_update,
  (hash_final)  sha384_final,
};

mircproc sha384
{
  unsigned char digest[SHA384_DIGEST_SIZE];
  sha384_ctx ctx;

  return hash(data, &sha384_func, digest, sizeof(digest), &ctx, mWnd);
}

hash_func sha512_func = {
  (hash_init)   sha512_init,
  (hash_update) sha512_update,
  (hash_final)  sha512_final,
};

mircproc sha512
{
  unsigned char digest[SHA512_DIGEST_SIZE];
  sha512_ctx ctx;

  return hash(data, &sha512_func, digest, sizeof(digest), &ctx, mWnd);
}
